@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011, 2012 */
+/* Copyright (c) Philip Hazel, 2009, 2011, 2012, 2013 */
 
 /* Error handling routines */
 
@@ -176,10 +176,13 @@ static error_struct error_data[] = {
                "%s while generating output" },
 { ec_disaster, "internal error: absolute page y position unset for reference "
                "to %s while generating output" },
-{ ec_disaster, "too many nested lists" }
+{ ec_disaster, "too many nested lists" },
+/* 115 - 119 */
+{ ec_noerror,  "'%s' is deprecated: use '%s' instead" },
+{ ec_disaster, "internal error: font for %s list has not been set up" }
 };
 
-#define error_maxerror 114
+#define error_maxerror 116
 
 
 
@@ -220,8 +223,11 @@ else
     if (suppress_warnings) return FALSE;
     (void)fprintf(stderr, "** Warning: ");
     }
-  else if (ec > ec_warning)
-    (void)fprintf(stderr, "** Error: ");
+  else
+    {
+    if (ec > ec_warning) (void)fprintf(stderr, "** Error: ");
+      else (void)fprintf(stderr, "** ");
+    }
   (void)vfprintf(stderr, error_data[n].text, ap);
   (void)fprintf(stderr, "\n");
   }
