@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011 */
+/* Copyright (c) Philip Hazel, 2009, 2011, 2013 */
 
 /* This module contains functions related to fonts. */
 
@@ -861,7 +861,7 @@ for (i = item_list; i != NULL; i = i->next)
   if (Ustrcmp(name, "?sdop") == 0)
     {
     pin_change_font_assign(i);
-    pin_change_list_params(i);
+    pin_change_list_params(i, TRUE);
     continue;
     }
 
@@ -1088,8 +1088,10 @@ for (i = item_list; i != NULL; i = i->next)
         vf = misc_malloc(sizeof(vfontstr));
         vf->family = FFAM_EXOTIC;
         vf->type = 0;
-        vf->size = pointsize;
-        vf->leading = leading;
+        vf->size = MULDIV(pointsize, scale_typesize_base,
+          scale_typesize_base_orig);
+        vf->leading = MULDIV(leading, scale_typesize_base,
+          scale_typesize_base_orig);
         vf->pnumber = 0;
         vf->afont = NULL;
         vf->sfont[0] = vf->sfont[1] = NULL;
@@ -1176,31 +1178,29 @@ for (i = item_list; i != NULL; i = i->next)
     else
       i->p.txtblk->vfont = font_used(current_vfont, NULL);
 
-    /* Handle tags at the start of items in itemized and ordered lists. At the
-    moment, we stick with the family and size of the main or footnote fonts,
-    but there are parameters to change the type, so we must ensure that a
-    suitable font exists. */
+    /* Handle tags at the start of items in itemized and ordered lists. The
+    vfont for these lists is a local parameter that may change in the course of
+    a file. Therefore, take a copy here and ensure that a font with its
+    characteristics is on the used list. In a footnote, adjust the font size
+    and leading. If the copy isn't actually needed (because there's already a
+    suitable font on the list), free the memory. */
 
     if (startitem && (initemizedlist || inorderedlist))
       {
-      int fonttype = initemizedlist? ilist_fs : olist_fs;
-      vfontstr *lf = (fonts == FONTS_FOOTNOTE)?
-        &footnote_maintext_vfont : &maintext_vfont;
+      vfontstr *lf = initemizedlist? &ilist_tag_vfont : &olist_tag_vfont;
+      vfontstr *v = misc_malloc(sizeof(vfontstr));
+      *v = *lf;
 
-      if (lf->type != fonttype)
+      if (fonts == FONTS_FOOTNOTE)
         {
-        vfontstr *v = misc_malloc(sizeof(vfontstr));
-        v->next = NULL;
-        v->family = lf->family;
-        v->type = fonttype;
-        v->size = lf->size;
-        v->leading = lf->leading;
-        v->pnumber = -1;
-        v->afont = NULL;
-        memset(v->sfont, 0, sizeof(v->sfont));
-        if ((lf = font_used(v, NULL)) != v) free(v);
+        v->size = MULDIV(v->size, footnote_maintext_vfont.size,
+          maintext_vfont.size);
+        v->leading = MULDIV(v->leading, footnote_maintext_vfont.leading,
+          maintext_vfont.leading);
         }
 
+      if ((lf = font_used(v, NULL)) != v) free(v);
+
       /* Having now found the font, for an itemized list with an overriding
       bullet mark, we must ensure that an appropriate auxiliary font is set up
       if necessary for the bullet character(s). Finding a character's width
@@ -1209,7 +1209,6 @@ for (i = item_list; i != NULL; i = i->next)
 
       if (initemizedlist && bullet >= 0)
         {
-        lf = font_used(lf, NULL);       /* Needed in case bypassed above */
         font_loadtables(lf->afont);
         if (bullet > 0)
           (void)font_charwidth(bullet, lf, NULL);
