@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011 */
+/* Copyright (c) Philip Hazel, 2009, 2011, 2013 */
 
 /* Allocate storage and initialize global variables, apart from those that are
 tables of some kind. Those are in datatables.c. */
@@ -116,6 +116,7 @@ uschar       *read_what                  = NULL;
 item         *revdescription_item_list   = NULL;
 
 int           scale_typesize_base        = 11000;
+int           scale_typesize_base_orig   = 11000;
 uschar       *sdop_share                 = NULL;
 BOOL          subscript_small            = TRUE;
 int           subscript_down             = 33;
@@ -174,6 +175,14 @@ vfontstr      formalpara_title_vfont = { NULL, FFAM_SERIF,  FTYPE_BOLD,     1100
 vfontstr      note_title_vfont       = { NULL, FFAM_SERIF,  FTYPE_ITALIC,   11000, 1000, 0, NULL, { NULL, NULL } };
 vfontstr      sidebar_title_vfont    = { NULL, FFAM_SERIF,  FTYPE_BOLD,     11000, 1000, 0, NULL, { NULL, NULL } };
 
+/* The list tag vfonts are reset from maintext_vfont at the start of the
+appropriate scans because thay may change during a document. */
+
+vfontstr      ilist_tag_vfont;
+int           ilist_tag_colour[3];
+vfontstr      olist_tag_vfont;
+int           olist_tag_colour[3];
+
 vfontstr      boittext_vfont = { NULL, FFAM_SERIF,    FTYPE_BOLDITALIC, 11000, 1000, 0, NULL, { NULL, NULL } };
 vfontstr      boldtext_vfont = { NULL, FFAM_SERIF,    FTYPE_BOLD,       11000, 1000, 0, NULL, { NULL, NULL } };
 vfontstr      italtext_vfont = { NULL, FFAM_SERIF,    FTYPE_ITALIC,     11000, 1000, 0, NULL, { NULL, NULL } };
@@ -411,11 +420,8 @@ int           replaceable_fs = FS_ITALIC;
 int           userinput_fs   = FS_MONO;
 int           varname_fs     = FS_ITALIC;
 
-int           ilist_fs;       /* The defaults are reset several times */
-int           olist_fs;       /* as these are local parameters. */
 uschar       *olist_format;
 
-
 BOOL          chapter_skip_head = FALSE;
 
 /* The "before" values for a chapter do not apply to normal chapters (or
@@ -577,7 +583,7 @@ to set this all up with a single initialization - got tangled in C incomplete
 types - and so I set up subvectors instead. Even so, I still needed the casts
 in the final vector to avoid compiler warnings about incompatible types. */
 
-uschar  *toc_line_chapter_strings[] = {
+uschar  *toc_line_chapter_strings[TOC_LINE_STRING_COUNT] = {
          US"<emphasis role='bold'>",    /* Start of line */
          US"",                          /* Before number */
          US".&nbsp;&nbsp;",             /* After number */
@@ -585,7 +591,7 @@ uschar  *toc_line_chapter_strings[] = {
          US"<emphasis role='bold'>",    /* Before page number */
          US"</emphasis>" };             /* After page number */
 
-uschar  *toc_line_sect1_strings[] = {
+uschar  *toc_line_sect1_strings[TOC_LINE_STRING_COUNT] = {
          US"&nbsp;&nbsp;&nbsp;&nbsp;",  /* Start of line */
          US"",                          /* Before number */
          US"&nbsp;&nbsp;",              /* After number */
@@ -593,7 +599,7 @@ uschar  *toc_line_sect1_strings[] = {
          US"",                          /* Before page number */
          US"" };                        /* After page number */
 
-uschar  *toc_line_sect2_strings[] = {
+uschar  *toc_line_sect2_strings[TOC_LINE_STRING_COUNT] = {
          US"&nbsp;&nbsp;&nbsp;&nbsp;"
            "&nbsp;&nbsp;&nbsp;&nbsp;",  /* Start of line */
          US"",                          /* Before number */
