@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009 */
+/* Copyright (c) Philip Hazel, 2009, 2011 */
 
 /* This module contains code for creating one or more indexes. */
 
@@ -218,7 +218,6 @@ return xc - yc;
 }
 
 
-
 /* When texts are identical, we compare the fonts. The first function does the
 compare for a given <primary>, <secondary>, or <tertiary> entry. In sync, scan
 the #PCDATA items, comparing lengths and fonts. If the fonts are identical,
@@ -378,7 +377,7 @@ return ptrs[0] != NULL;
 
 
 /*************************************************
-*       Add page number(s)/"see" to output       *
+*     Add page number(s) or "see" to output      *
 *************************************************/
 
 /* This function is called to add page number(s) or a "see" or "seealso" item
@@ -413,8 +412,8 @@ if (spage == INT_MAX && see != NULL)
     US"<emphasis>see</emphasis> " :
     US"<emphasis>see also</emphasis> ";
 
-  (void)read_string(prefix, nest_stack, nest_ptrptr);
-  (void)read_string(seetext, nest_stack, nest_ptrptr);
+  (void)read_string(prefix, nest_stack, nest_ptrptr, 0);
+  (void)read_string(seetext, nest_stack, nest_ptrptr, 0);
 
   see->prev->next = see->partner->next;
   see->partner->next->prev = see->prev;
@@ -448,14 +447,16 @@ if (spage != lpage)
   {
   lpage = spage;
   (void)sprintf(CS buffer, "%s%d", prefix, spage);
-  (void)read_string(buffer, nest_stack, nest_ptrptr);
+  (void)read_string(buffer, nest_stack, nest_ptrptr, PIN_IREF);
+  read_addto->p.txtblk->colour = xref_packed_colour;
   }
 
 if (epage > spage)
   {
   lpage = epage;
   (void)sprintf(CS buffer, "%s%d", S_EN_DASH, epage);
-  (void)read_string(buffer, nest_stack, nest_ptrptr);
+  (void)read_string(buffer, nest_stack, nest_ptrptr, PIN_IREF);
+  read_addto->p.txtblk->colour = xref_packed_colour;
   }
 
 return lpage;
@@ -771,7 +772,7 @@ lpage = 0;                                 /* Last output number */
 (void)sprintf(CS buffer,
   "<?sdop page_columns=\"%d\" page_column_separation=\"%s\"?>",
     index_page_columns, misc_formatfixed(index_page_colsep));
-(void)read_string(buffer, nest_stack, &nest_stackptr);
+(void)read_string(buffer, nest_stack, &nest_stackptr, 0);
 
 for (k = 0; k < index_entry_count; k++)
   {
@@ -821,7 +822,7 @@ for (k = 0; k < index_entry_count; k++)
 
       continue;
       }
-    (void)read_string(US"</para>", nest_stack, &nest_stackptr);
+    (void)read_string(US"</para>", nest_stack, &nest_stackptr, 0);
     plevel = j;
     }
 
@@ -846,9 +847,9 @@ for (k = 0; k < index_entry_count; k++)
         title[1] = '\n';
         title[2] = 0;
         }
-      (void)read_string(US"<section><title>", nest_stack, &nest_stackptr);
-      (void)read_string(title, nest_stack, &nest_stackptr);
-      (void)read_string(US"</title></section>\n", nest_stack, &nest_stackptr);
+      (void)read_string(US"<section><title>", nest_stack, &nest_stackptr, 0);
+      (void)read_string(title, nest_stack, &nest_stackptr, 0);
+      (void)read_string(US"</title></section>\n", nest_stack, &nest_stackptr, 0);
       ixhnext++;
       }
     }
@@ -864,11 +865,11 @@ for (k = 0; k < index_entry_count; k++)
     if (this == NULL) break;              /* There's no text at this level */
 
     if (j > plevel)                       /* Round this loop more than once */
-      (void)read_string(US"</para>", nest_stack, &nest_stackptr);
+      (void)read_string(US"</para>", nest_stack, &nest_stackptr, 0);
 
-    (void)read_string(US"<para>", nest_stack, &nest_stackptr);
+    (void)read_string(US"<para>", nest_stack, &nest_stackptr, 0);
     for (jj = 0; jj < j; jj++)
-      (void)read_string(US S_HARD_SPACE4, nest_stack, &nest_stackptr);
+      (void)read_string(US S_HARD_SPACE4, nest_stack, &nest_stackptr, 0);
 
     this->prev->next = this->partner->next;
     this->partner->next->prev = this->prev;
@@ -895,18 +896,22 @@ for (k = 0; k < index_entry_count; k++)
 column settings. */
 
 if (iprev != NULL)
-  (void)read_string(US"</para>", nest_stack, &nest_stackptr);
+  (void)read_string(US"</para>", nest_stack, &nest_stackptr, 0);
 
 (void)sprintf(CS buffer,
   "<?sdop page_columns=\"%d\" page_column_separation=\"%s\"?>",
     page_columns_save, misc_formatfixed(page_colsep_save));
-(void)read_string(buffer, nest_stack, &nest_stackptr);
+(void)read_string(buffer, nest_stack, &nest_stackptr, 0);
 
 /* Tidy up the sort vector before returning */
 
 misc_free(index_sort_vector, sizeof(item *) * index_entry_count);
 read_what = NULL;
 read_linenumber = 0;
+
+DEBUG(D_indexfull)
+  debug_print_item_list(item_list, "after creating index items");
+
 return rc;
 }
 
