@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011, 2012 */
+/* Copyright (c) Philip Hazel, 2009, 2011, 2012, 2013 */
 
 /* This module contains functions for doing things to paragraphs. */
 
@@ -1125,7 +1125,6 @@ int spacewidth = 0;
 int spacecount = 0;
 int lastc = -1;
 int startoffset = *offsetptr;
-int hyphenwidth;
 int chtype;
 BOOL kerning, hyphening, fiok, stdencoding;
 BOOL okhyphen = TRUE;
@@ -1182,10 +1181,9 @@ stdencoding = tb->vfont->afont->stdencoding;
 p = tb->string + startoffset;
 ctb = tb;    /* Save for later copying */
 
-/* Initialize the line depth and hyphenwidth from the first font. */
+/* Initialize the line depth from the first font. */
 
 maxlinedepth = tb->vfont->size + tb->vfont->leading;
-hyphenwidth = font_charwidth('-', tb->vfont, NULL);
 
 /* If we are filling, white space at the start of a line is ignored. This can
 occur at the start of a paragraph when spaces follow <para> before the text
@@ -1254,7 +1252,6 @@ for (;;)
     stdencoding = tb->vfont->afont->stdencoding;
     newlinedepth = tb->vfont->size + tb->vfont->leading;
     if (newlinedepth > maxlinedepth) maxlinedepth = newlinedepth;
-    hyphenwidth = font_charwidth('-', tb->vfont, NULL);
     }
 
   /* Get the next character. Certain characters are handled specially, provided
@@ -1935,10 +1932,10 @@ int currlistendent[MAXLISTNEST];
 
 int  prev_justify = 0;
 int  prev_read_linenumber = 0;
+int  prev_skipped_warning = 0;
 int  prev_widest_line = 0;
 
 BOOL skipped_warning = FALSE;
-BOOL prev_skipped_warning = FALSE;
 
 currlistindent[0] = 0;
 currlistendent[0] = 0;
@@ -1989,7 +1986,7 @@ for (i = item_list->next; i != NULL; i = i->next)
   else if (Ustrcmp(i->name, "row") == 0)
     {
     colnumber = 0;
-    prev_skipped_warning = FALSE;
+    prev_skipped_warning = 0;
     continue;
     }
 
@@ -2109,7 +2106,7 @@ for (i = item_list->next; i != NULL; i = i->next)
       overflow goes over this column too, in which case we either give an error
       (if this is the last column), or set up to check at the next one. */
 
-      if (prev_skipped_warning)
+      if (prev_skipped_warning > 0)
         {
         int overflow = 0;
         int prev_plus_colspace = td->coldata[colnumber-1].width +
@@ -2150,18 +2147,20 @@ for (i = item_list->next; i != NULL; i = i->next)
           (td->coldata[colnumber].width - widest_line)/
             ((justify == J_CENTRE)? 2 : 1);
 
-        /* Give error if there is an overprinting overflow */
+        /* Give an error for a previous column if there is an overprinting
+        overflow. */
 
         if (overflow > 0)
           {
           read_linenumber = prev_read_linenumber;
-          (void)error(62, misc_formatfixed(overflow), colnumber);
+          (void)error(62, misc_formatfixed(overflow),
+            colnumber - prev_skipped_warning);
           }
         }
 
       /* Remember this column's characteristics */
 
-      prev_skipped_warning = skipped_warning;
+      if (skipped_warning) prev_skipped_warning++;
       prev_widest_line = widest_line;
       prev_justify = justify;
       prev_read_linenumber = read_linenumber;
