@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011 */
+/* Copyright (c) Philip Hazel, 2009, 2011, 2013 */
 
 /* This module contains the main program and initialization functions. */
 
@@ -233,7 +233,7 @@ int i;
   "  -S <directories>          list of additional SDoP share directories\n"
   "  -w                        warn for unsupported DocBook features (default)\n"
   "  -wc                       warn for unsupported characters (default)\n"
-  "  -v                        show version information\n"
+  "  -v or --version           show version information\n"
   );
 
 (void)fprintf(stderr,
@@ -317,7 +317,8 @@ for (i = 1; i < argc; i++)
     warn_unsupported = TRUE;
     warn_unsupported_set = TRUE;
     }
-  else if (Ustrcmp(arg, "-v") == 0)
+  else if (Ustrcmp(arg, "-v") == 0 ||
+           Ustrcmp(arg, "--version") == 0)
     {
     (void)fprintf(stdout, "SDoP version %s %s\n", SDOP_VERSION, SDOP_DATE);
     (void)fprintf(stdout, "JPEG support: %s\n",
