@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2010, 2011 */
+/* Copyright (c) Philip Hazel, 2009, 2010, 2011, 2013 */
 
 /* This module contains code for creating a table of contents. */
 
@@ -25,6 +25,7 @@ static BOOL firstchapter;
 static BOOL firstsection;
 static BOOL in_index;
 static BOOL in_section;
+static BOOL index_headings_pdf_toc;
 
 
 /*************************************************
@@ -141,6 +142,8 @@ sections. */
 
 if (Ustrcmp(i->name, "?sdop") == 0)
   {
+  paramstr *p = misc_param_find(i, US"index_headings_pdf_toc");
+  if (p != NULL) index_headings_pdf_toc = Ustrcmp(p->value, "yes") == 0;
   (void)misc_yesno_vector(i, US"numbertitles", number_sections, MAXSECTDEPTH);
   if (misc_yesno_vector(i, US"toc_sections", toc_sections, MAXSECTDEPTH))
     memcpy(toc_printed_sections, toc_sections, sizeof(toc_sections));
@@ -177,8 +180,8 @@ else if (Ustrcmp(i->name, "preface")  == 0 ||
   s = (Ustrcmp(i->next->name, "#RAWTITLE") == 0)?
     i->next->p.lngthstrng->value : UNTITLED;
 
-  /* For all but the first chapter, insert a blank line before it, if
-  so configured. */
+  /* Set up for a chapter/preface/appendix/index. For all but the first, insert
+  a blank line before it, if so configured. */
 
   if (!is_section)
     {
@@ -190,13 +193,39 @@ else if (Ustrcmp(i->name, "preface")  == 0 ||
     firstsection = TRUE;
     }
 
-  /* For a section, increase the depth. Skip if we are too deep for the TOC
-  or within an index. If it's the first section in a chapter, insert a blank
-  line if so configured. */
+  /* Set up for sections, subsections, etc. Within an index, where there is
+  only ever one level of section, skip unless index_headings_pdf_toc is TRUE.
+  This is independent of toc_sections, but index sections are present only if
+  index_headings_enabled is TRUE (the default). Sections within an index are
+  never included in the printed TOC, but a pdfmark is created for them if
+  index_headings_pdf_toc is TRUE. */
 
   else
     {
-    if (!toc_sections[++toc_depth] || in_index) return;
+    toc_depth++;
+
+    if (in_index)
+      {
+      if (index_headings_pdf_toc)
+        {
+        lengthstring *ls = misc_find_title(i, US"title");
+        pdf = misc_malloc(sizeof(pdfmarkstr) + Ustrlen(ls->value));
+        pdf->next = NULL;
+        *toc_pdftail = pdf;
+        toc_pdftail = &(pdf->next);
+        pdf->page = toc_page;
+        pdf->level = toc_depth;
+        pdf->ispreface = ispreface;
+        Ustrcpy(pdf->text, ls->value);
+        }
+      return;
+      }
+
+    /* For a normal section, increase the depth. Skip if we are too deep for
+    the TOC. If this is the first section in a chapter, insert a blank line if
+    so configured. */
+
+    if (!toc_sections[toc_depth]) return;
     if (firstsection && toc_chapter_blanks[1] && toc_printed_sections[1])
       {
       read_string(US"<row><entry>&nbsp;</entry></row>", nest_stack,
@@ -205,7 +234,8 @@ else if (Ustrcmp(i->name, "preface")  == 0 ||
     firstsection = FALSE;
     }
 
-  /* Find the configured strings for building the line */
+  /* Handle cases that go into the printed TOC (everything except sections in
+  indexes). Find the configured strings for building the line. */
 
   strings = toc_line_strings[(toc_depth >= toc_line_string_count)?
     toc_line_string_count - 1 : toc_depth];
@@ -325,6 +355,7 @@ firstchapter = TRUE;
 firstsection = TRUE;
 in_index = FALSE;
 in_section = FALSE;
+index_headings_pdf_toc = FALSE;
 
 toc_depth = 0;
 toc_pdftail = &toc_pdfmarks;
