@@ -2,7 +2,7 @@
 *          sdop - Simple DocBook Processor       *
 *************************************************/
 
-/* Copyright (c) Philip Hazel, 2009, 2011 */
+/* Copyright (c) Philip Hazel, 2009, 2011, 2013 */
 
 /* This module contains code for writing the final output file. */
 
@@ -473,7 +473,6 @@ int ytopframe = 0;
 int tabledent = 0;
 int justspaced = -1;
 int toc_fill_width = 0;
-int toc_fill_length = 0;
 int ytopcol = ypos;
 int snum, sden, stretchspace;
 int chfirst = 0, chlast = 0;
@@ -629,6 +628,18 @@ for (i = pagestart->next;
     }
   read_linenumber = i->linenumber;
 
+  /* If we hit an ?sdop item, check for a change to the multicolumning or to
+  list parameters. */
+
+  if (Ustrcmp(name, "?sdop") == 0)
+    {
+    int oldcols = page_columns;
+    pin_change_columns(i);
+    if (oldcols != page_columns) ytopcol = ypos;
+    pin_change_list_params(i, FALSE);
+    continue;
+    }
+
   /* No need to do more if suppressing */
 
   if (suppress) continue;
@@ -652,6 +663,13 @@ for (i = pagestart->next;
     {
     for ( ; i != NULL && Ustrcmp(i->name, "#PDATA") != 0; i = i->next)
       {
+      if (Ustrcmp(i->name, "?sdop") == 0)
+        {
+        int oldcols = page_columns;
+        pin_change_columns(i);
+        if (oldcols != page_columns) ytopcol = ypos;
+        pin_change_list_params(i, FALSE);
+        }
       if (Ustrcmp(i->name, "footnote") == 0)
         {
         infootnote = TRUE;
@@ -693,18 +711,6 @@ for (i = pagestart->next;
     continue;
     }
 
-  /* If we hit an ?sdop item, check for a change to the multicolumning or to
-  list parameters. */
-
-  else if (Ustrcmp(name, "?sdop") == 0)
-    {
-    int oldcols = page_columns;
-    pin_change_columns(i);
-    if (oldcols != page_columns) ytopcol = ypos;
-    pin_change_list_params(i);
-    continue;
-    }
-
   /* If we hit a <figure>, move its title to below the figure, and flag its
   text as a figure title. */
 
@@ -842,7 +848,6 @@ for (i = pagestart->next;
         GETCHARINC(c, pp);
         toc_fill_width += font_charwidth(c, toc_fill_vfont_ptr, NULL);
         }
-      toc_fill_length = Ustrlen(toc_fill_string);
       }
 
     /* If not at the top of a page, ensure enough space, and do the stretch
@@ -1278,45 +1283,48 @@ for (i = pagestart->next;
     if (marklistitem)
       {
       vfontstr *mtvfont, *olvfont;
-      int back, fonttype;
+      int back, num, den, colour;
+
+      if (infootnote)
+        {
+        den = maintext_vfont.size;
+        num = footnote_maintext_vfont.size;
+        }
+      else num = den = 1;
 
       if (listcount < 0)    /* Itemized list */
         {
         back = ilistpara_layparm.indent;
-        fonttype = ilist_fs;
+        mtvfont = &ilist_tag_vfont;
+        colour = (ilist_tag_colour[0] << 20) | (ilist_tag_colour[1] << 10) |
+                 (ilist_tag_colour[2]);
         }
       else                  /* Ordered list */
         {
         back = olistpara_layparm.indent;
-        fonttype = olist_fs;
+        mtvfont = &olist_tag_vfont;
+        colour = (olist_tag_colour[0] << 20) | (olist_tag_colour[1] << 10) |
+                 (olist_tag_colour[2]);
         }
 
       ccount += cprintf("%s ", misc_formatfixed(indent - back));
       ccount += cprintf("%s Mt ", misc_formatfixed(ypos));
 
-      /* If the line's vfont does not have the same family and size as the main
-      text font, and the required font type, seek one that does. A future
-      objective is to invent a way of specifying what the family and size
-      should be. */
+      /* Find the vfont that corresponds to the current parameters of the
+      list's vfont (which may change during the input). Note that the size is
+      adjusted if we are in a footnote. */
 
-      olvfont = ol->txtblk->vfont;
-      mtvfont = do_fn? &footnote_maintext_vfont : &maintext_vfont;
-      if (olvfont->family != mtvfont->family ||
-          olvfont->type   != fonttype ||
-          olvfont->size   != mtvfont->size)
+      for (olvfont = vfont_list; olvfont != NULL; olvfont = olvfont->next)
         {
-        vfontstr *v;
-        for (v = vfont_list; v != NULL; v = v->next)
-          {
-          if (v->family == mtvfont->family &&
-              v->type   == fonttype &&
-              v->size   == mtvfont->size)
-            break;
-          }
-        if (v != NULL) olvfont = v;
+        if (olvfont->family == mtvfont->family &&
+            olvfont->type   == mtvfont->type &&
+            olvfont->size   == (mtvfont->size*num)/den)
+          break;
         }
+      if (olvfont == NULL)
+        error(116, (listcount < 0)? "itemized" : "ordered");  /* Fatal */
 
-      check_colour(0);   /* Black */
+      check_colour(colour);
 
       /* Itemized list item */
 
@@ -2209,15 +2217,20 @@ write_pbody_page(item *i, int pagenumber, uschar *pagetext, hfstr *hf,
 {
 BOOL foundsection = FALSE;
 int footnote_depth = 0;
-uschar buffer[1024];
-uschar *tptr;
+vfontstr ilist_top_vfont, olist_top_vfont;
+int ilist_top_colour[3], olist_top_colour[3];
 item *nexti;
 item *ii;
 
 DEBUG(D_any) running_page(US"", pagetext);
 
-tptr = buffer;
-*tptr = 0;
+/* Save list parameters at the start of the page in case they have to be reset
+for a footnote scan. */
+
+ilist_top_vfont = ilist_tag_vfont;
+olist_top_vfont = olist_tag_vfont;
+memcpy(ilist_top_colour, ilist_tag_colour, 3*sizeof(int));
+memcpy(olist_top_colour, olist_tag_colour, 3*sizeof(int));
 
 /* Scan the page for
 
@@ -2346,9 +2359,15 @@ DEBUG(D_write) debug_printf("Processing page data\n");
 ypos = ytoppage = page_full_length + margin_bottom - page_head_length;
 nexti = write_page(i, pagenumber, FALSE);
 
+/* Reset ilist and olist parameters for a footnote scan. */
+
 if (footnote_depth > 0)
   {
   DEBUG(D_write) debug_printf("Footnote depth=%d\n", footnote_depth);
+  ilist_tag_vfont = ilist_top_vfont;
+  olist_tag_vfont = olist_top_vfont;
+  memcpy(ilist_tag_colour, ilist_top_colour, 3*sizeof(int));
+  memcpy(olist_tag_colour, olist_top_colour, 3*sizeof(int));
   ypos = ytoppage = margin_bottom + page_foot_length + footnote_depth;
   draw_rule(footnote_line_thickness, margin_left, ypos + 1000, 1,
     footnote_line_length, 0);
